summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSimon McVittie <simon.mcvittie@collabora.co.uk>2013-11-12 11:30:14 +0000
committerSimon McVittie <simon.mcvittie@collabora.co.uk>2013-11-12 11:30:14 +0000
commit12195fcde9e353b8cd9d750ee714d3f5ab8c22fd (patch)
tree3dfa55cd09b9d7191cc77fb0f949d5fc815aa40c
parent136ef5f3b5b307a9d70215ac1f0684b5c50e2cb4 (diff)
Re-namespace to im.telepathy.v1
Reviewed-by: Xavier Claessens <xavier.claessens@collabora.co.uk> Bug: https://bugs.freedesktop.org/show_bug.cgi?id=71262 [depend on telepathy-glib 0.99.5 to stay in sync -smcv] Signed-off-by: Simon McVittie <simon.mcvittie@collabora.co.uk>
-rw-r--r--.gitignore4
-rw-r--r--configure.ac2
-rw-r--r--data/Makefile.am4
-rw-r--r--data/salut.service.in2
-rw-r--r--extensions/Connection_Future.xml12
-rw-r--r--extensions/OLPC_Activity_Properties.xml16
-rw-r--r--extensions/OLPC_Buddy_Info.xml28
-rw-r--r--extensions/Salut_Plugin_Test.xml2
-rw-r--r--plugins/test.c2
-rw-r--r--src/connection.c4
-rw-r--r--src/file-transfer-channel.c4
-rw-r--r--src/muc-manager.c4
-rw-r--r--src/roomlist-channel.c8
-rw-r--r--src/tube-dbus.c4
-rw-r--r--src/tube-stream.c4
-rw-r--r--tests/twisted/avahi/caps-self.py2
-rw-r--r--tests/twisted/avahi/close-local-pending-room.py2
-rw-r--r--tests/twisted/avahi/file-transfer/file_transfer_helper.py8
-rw-r--r--tests/twisted/avahi/muc-invite.py2
-rw-r--r--tests/twisted/avahi/olpc-activity-announcements.py2
-rw-r--r--tests/twisted/avahi/tubes/tubetestutil.py2
-rw-r--r--tests/twisted/avahi/tubes/two-muc-dbus-tubes.py4
-rw-r--r--tests/twisted/constants.py2
-rw-r--r--tests/twisted/sidecars.py2
-rw-r--r--tests/twisted/tools/Makefile.am4
-rw-r--r--tests/twisted/tools/salut.service.in2
26 files changed, 66 insertions, 66 deletions
diff --git a/.gitignore b/.gitignore
index ec554dd4..bfec94d9 100644
--- a/.gitignore
+++ b/.gitignore
@@ -81,7 +81,7 @@ m4/lt~obsolete.m4
/coverage/
-data/im.telepathy1.ConnectionManager.salut.service
+data/im.telepathy.v1.ConnectionManager.salut.service
data/*.service
data/salut.manager
@@ -118,7 +118,7 @@ tests/twisted/tools/core
tests/twisted/tools/exec-with-log.sh
tests/twisted/tools/salut-testing.log*
tests/twisted/tools/tmp-session-bus.conf
-tests/twisted/tools/im.telepathy1.ConnectionManager.salut.service
+tests/twisted/tools/im.telepathy.v1.ConnectionManager.salut.service
tests/twisted/tools/refdbg.log
/tests/twisted/with-session-bus*.address
/tests/twisted/with-session-bus*.pid
diff --git a/configure.ac b/configure.ac
index 69f050d2..035564cc 100644
--- a/configure.ac
+++ b/configure.ac
@@ -187,7 +187,7 @@ PKG_CHECK_MODULES(LIBXML2, [libxml-2.0])
AC_SUBST(LIBXML2_CFLAGS)
AC_SUBST(LIBXML2_LIBS)
-TELEPATHY_GLIB_REQUIRED=0.99.2
+TELEPATHY_GLIB_REQUIRED=0.99.5
AC_DEFINE([TP_SEAL_ENABLE], [], [Prevent to use sealed variables])
AC_DEFINE([TP_DISABLE_SINGLE_INCLUDE], [], [Disable single header include])
AC_DEFINE([TP_VERSION_MIN_REQUIRED], [TP_VERSION_1_0], [Ignore post 1.0 deprecations])
diff --git a/data/Makefile.am b/data/Makefile.am
index 049070c6..296387b7 100644
--- a/data/Makefile.am
+++ b/data/Makefile.am
@@ -4,12 +4,12 @@ managerdir = $(datadir)/telepathy/managers
manager_DATA = salut.manager
servicedir = $(datadir)/dbus-1/services
-service_DATA = im.telepathy1.ConnectionManager.salut.service
+service_DATA = im.telepathy.v1.ConnectionManager.salut.service
# We don't use the full filename for the .in because > 99 character filenames
# in tarballs are non-portable (and automake 1.8 doesn't let us build
# non-archaic tarballs)
-im.telepathy1.ConnectionManager.salut.service: salut.service.in \
+im.telepathy.v1.ConnectionManager.salut.service: salut.service.in \
Makefile
$(AM_V_GEN)sed -e "s|[@]libexecdir[@]|$(libexecdir)|" $< > $@
diff --git a/data/salut.service.in b/data/salut.service.in
index 60303685..fe080b0f 100644
--- a/data/salut.service.in
+++ b/data/salut.service.in
@@ -1,3 +1,3 @@
[D-BUS Service]
-Name=im.telepathy1.ConnectionManager.salut
+Name=im.telepathy.v1.ConnectionManager.salut
Exec=@libexecdir@/telepathy-salut
diff --git a/extensions/Connection_Future.xml b/extensions/Connection_Future.xml
index a578a888..ad08642e 100644
--- a/extensions/Connection_Future.xml
+++ b/extensions/Connection_Future.xml
@@ -20,9 +20,9 @@ License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
USA.</p>
</tp:license>
- <interface name="im.telepathy1.Connection.FUTURE"
+ <interface name="im.telepathy.v1.Connection.FUTURE"
tp:causes-havoc='experimental'>
- <tp:requires interface="im.telepathy1.Connection"/>
+ <tp:requires interface="im.telepathy.v1.Connection"/>
<method name="EnsureSidecar" tp:name-for-bindings="Ensure_Sidecar">
<tp:added version="0.19.UNRELEASED"/>
@@ -75,12 +75,12 @@ USA.</p>
in a dictionary, build a proxy object from the value). More
“plural” plugins are likely to want to implement new types of
<tp:dbus-ref
- namespace="im.telepathy1">Channel</tp:dbus-ref>
+ namespace="im.telepathy.v1">Channel</tp:dbus-ref>
instead.</p>
</tp:rationale>
</tp:docstring>
- <tp:error name="im.telepathy1.Error.NotImplemented">
+ <tp:error name="im.telepathy.v1.Error.NotImplemented">
<tp:docstring>
The requested sidecar is not implemented by this connection manager,
or a necessary server-side component does not exist. (FIXME: split
@@ -91,7 +91,7 @@ USA.</p>
</tp:docstring>
</tp:error>
- <tp:error name="im.telepathy1.Error.ServiceBusy">
+ <tp:error name="im.telepathy.v1.Error.ServiceBusy">
<tp:docstring>
A server-side component needed by the requested sidecar reported it
is currently too busy, or did not respond for some
@@ -99,7 +99,7 @@ USA.</p>
</tp:docstring>
</tp:error>
- <tp:error name="im.telepathy1.Error.Cancelled">
+ <tp:error name="im.telepathy.v1.Error.Cancelled">
<tp:docstring>
The connection was disconnected while the sidecar was being set up.
</tp:docstring>
diff --git a/extensions/OLPC_Activity_Properties.xml b/extensions/OLPC_Activity_Properties.xml
index 4125cd50..babfd4f9 100644
--- a/extensions/OLPC_Activity_Properties.xml
+++ b/extensions/OLPC_Activity_Properties.xml
@@ -17,7 +17,7 @@ License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA</p>
</tp:license>
<interface name="org.laptop.Telepathy.ActivityProperties">
- <tp:requires interface="im.telepathy1.Connection"/>
+ <tp:requires interface="im.telepathy.v1.Connection"/>
<method name="SetProperties" tp:name-for-bindings="Set_Properties">
<arg direction="in" name="room" type="u">
@@ -35,9 +35,9 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA</p>
You have to be the owner of this activity.
</tp:docstring>
<tp:possible-errors>
- <tp:error name="im.telepathy1.Error.Disconnected"/>
- <tp:error name="im.telepathy1.Error.InvalidArgument"/>
- <tp:error name="im.telepathy1.Error.PermissionDenied"/>
+ <tp:error name="im.telepathy.v1.Error.Disconnected"/>
+ <tp:error name="im.telepathy.v1.Error.InvalidArgument"/>
+ <tp:error name="im.telepathy.v1.Error.PermissionDenied"/>
</tp:possible-errors>
</method>
@@ -56,8 +56,8 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA</p>
Get the properties of a particular activity.
</tp:docstring>
<tp:possible-errors>
- <tp:error name="im.telepathy1.Error.Disconnected"/>
- <tp:error name="im.telepathy1.Error.InvalidArgument"/>
+ <tp:error name="im.telepathy.v1.Error.Disconnected"/>
+ <tp:error name="im.telepathy.v1.Error.InvalidArgument"/>
</tp:possible-errors>
</method>
@@ -80,8 +80,8 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA</p>
</tp:rationale>
</tp:docstring>
<tp:possible-errors>
- <tp:error name="im.telepathy1.Error.Disconnected"/>
- <tp:error name="im.telepathy1.Error.InvalidArgument"/>
+ <tp:error name="im.telepathy.v1.Error.Disconnected"/>
+ <tp:error name="im.telepathy.v1.Error.InvalidArgument"/>
</tp:possible-errors>
</method>
diff --git a/extensions/OLPC_Buddy_Info.xml b/extensions/OLPC_Buddy_Info.xml
index 83bf916c..cdd9fb44 100644
--- a/extensions/OLPC_Buddy_Info.xml
+++ b/extensions/OLPC_Buddy_Info.xml
@@ -17,7 +17,7 @@ License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA</p>
</tp:license>
<interface name="org.laptop.Telepathy.BuddyInfo">
- <tp:requires interface="im.telepathy1.Connection"/>
+ <tp:requires interface="im.telepathy.v1.Connection"/>
<method name="SetProperties" tp:name-for-bindings="Set_Properties">
<arg direction="in" name="properties" type="a{sv}">
@@ -35,7 +35,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA</p>
(possibly immediately).</p>
</tp:docstring>
<tp:possible-errors>
- <tp:error name="im.telepathy1.Error.InvalidArgument"/>
+ <tp:error name="im.telepathy.v1.Error.InvalidArgument"/>
</tp:possible-errors>
</method>
@@ -54,8 +54,8 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA</p>
Get the properties of a particular contact.
</tp:docstring>
<tp:possible-errors>
- <tp:error name="im.telepathy1.Error.Disconnected"/>
- <tp:error name="im.telepathy1.Error.InvalidArgument"/>
+ <tp:error name="im.telepathy.v1.Error.Disconnected"/>
+ <tp:error name="im.telepathy.v1.Error.InvalidArgument"/>
</tp:possible-errors>
</method>
@@ -103,8 +103,8 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA</p>
Set the activities of the local user for this connection.
</tp:docstring>
<tp:possible-errors>
- <tp:error name="im.telepathy1.Error.Disconnected"/>
- <tp:error name="im.telepathy1.Error.InvalidArgument"/>
+ <tp:error name="im.telepathy.v1.Error.Disconnected"/>
+ <tp:error name="im.telepathy.v1.Error.InvalidArgument"/>
</tp:possible-errors>
</method>
@@ -128,8 +128,8 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA</p>
</tp:rationale>
</tp:docstring>
<tp:possible-errors>
- <tp:error name="im.telepathy1.Error.Disconnected"/>
- <tp:error name="im.telepathy1.Error.InvalidArgument"/>
+ <tp:error name="im.telepathy.v1.Error.Disconnected"/>
+ <tp:error name="im.telepathy.v1.Error.InvalidArgument"/>
</tp:possible-errors>
</method>
@@ -152,8 +152,8 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA</p>
Get the activities of a particular contact.
</tp:docstring>
<tp:possible-errors>
- <tp:error name="im.telepathy1.Error.Disconnected"/>
- <tp:error name="im.telepathy1.Error.InvalidArgument"/>
+ <tp:error name="im.telepathy.v1.Error.Disconnected"/>
+ <tp:error name="im.telepathy.v1.Error.InvalidArgument"/>
</tp:possible-errors>
</method>
@@ -196,8 +196,8 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA</p>
Set the current activity of the local user for this connection.
</tp:docstring>
<tp:possible-errors>
- <tp:error name="im.telepathy1.Error.Disconnected"/>
- <tp:error name="im.telepathy1.Error.InvalidArgument"/>
+ <tp:error name="im.telepathy.v1.Error.Disconnected"/>
+ <tp:error name="im.telepathy.v1.Error.InvalidArgument"/>
</tp:possible-errors>
</method>
@@ -223,8 +223,8 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA</p>
Get the current activity of a particular contact.
</tp:docstring>
<tp:possible-errors>
- <tp:error name="im.telepathy1.Error.Disconnected"/>
- <tp:error name="im.telepathy1.Error.InvalidArgument"/>
+ <tp:error name="im.telepathy.v1.Error.Disconnected"/>
+ <tp:error name="im.telepathy.v1.Error.InvalidArgument"/>
</tp:possible-errors>
</method>
diff --git a/extensions/Salut_Plugin_Test.xml b/extensions/Salut_Plugin_Test.xml
index d62c26b9..1bcde7b2 100644
--- a/extensions/Salut_Plugin_Test.xml
+++ b/extensions/Salut_Plugin_Test.xml
@@ -17,7 +17,7 @@ Lesser General Public License for more details.</p>
License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.</p>
</tp:license>
- <interface name="im.telepathy1.Salut.Plugin.Test">
+ <interface name="im.telepathy.v1.Salut.Plugin.Test">
<tp:docstring xmlns="http://www.w3.org/1999/xhtml">
<p>A sidecar interface implemented by a plugin used by the test
suite.</p>
diff --git a/plugins/test.c b/plugins/test.c
index 6ab15135..03c9a607 100644
--- a/plugins/test.c
+++ b/plugins/test.c
@@ -14,7 +14,7 @@ static void plugin_iface_init (
gpointer g_iface,
gpointer data);
-#define IFACE_TEST "im.telepathy1.Salut.Plugin.Test"
+#define IFACE_TEST "im.telepathy.v1.Salut.Plugin.Test"
static const gchar * const sidecar_interfaces[] = {
IFACE_TEST,
diff --git a/src/connection.c b/src/connection.c
index 07d4c592..9bf93166 100644
--- a/src/connection.c
+++ b/src/connection.c
@@ -1346,7 +1346,7 @@ salut_connection_get_alias (SalutConnection *self, TpHandle handle)
* salut_connection_request_aliases
*
* Implements D-Bus method RequestAliases
- * on interface im.telepathy1.Connection.Interface.Aliasing
+ * on interface im.telepathy.v1.Connection.Interface.Aliasing
*
*/
static void
@@ -1938,7 +1938,7 @@ data_forms_equal (GPtrArray *one,
*
* Implements D-Bus method UpdateCapabilities
* on interface
- * im.telepathy1.Connection.Interface.ContactCapabilities
+ * im.telepathy.v1.Connection.Interface.ContactCapabilities
*/
static void
salut_connection_update_capabilities (
diff --git a/src/file-transfer-channel.c b/src/file-transfer-channel.c
index a3621f99..0ac431ba 100644
--- a/src/file-transfer-channel.c
+++ b/src/file-transfer-channel.c
@@ -1188,7 +1188,7 @@ salut_file_transfer_channel_offer_file (SalutFileTransferChannel *self,
* salut_file_transfer_channel_accept_file
*
* Implements D-Bus method AcceptFile
- * on interface im.telepathy1.Channel.Type.FileTransfer
+ * on interface im.telepathy.v1.Channel.Type.FileTransfer
*/
static void
salut_file_transfer_channel_accept_file (TpSvcChannelTypeFileTransfer1 *iface,
@@ -1264,7 +1264,7 @@ salut_file_transfer_channel_accept_file (TpSvcChannelTypeFileTransfer1 *iface,
* salut_file_transfer_channel_provide_file
*
* Implements D-Bus method ProvideFile
- * on interface im.telepathy1.Channel.Type.FileTransfer
+ * on interface im.telepathy.v1.Channel.Type.FileTransfer
*/
static void
salut_file_transfer_channel_provide_file (
diff --git a/src/muc-manager.c b/src/muc-manager.c
index 30a0a814..86ff5478 100644
--- a/src/muc-manager.c
+++ b/src/muc-manager.c
@@ -360,12 +360,12 @@ salut_muc_manager_type_foreach_channel_class (GType type,
g_hash_table_insert (table, TP_IFACE_CHANNEL ".TargetHandleType",
handle_type_value);
- /* im.telepathy1.Channel.Type.Text */
+ /* im.telepathy.v1.Channel.Type.Text */
g_value_set_static_string (channel_type_value, TP_IFACE_CHANNEL_TYPE_TEXT);
func (type, table, muc_channel_allowed_properties,
user_data);
- /* im.telepathy1.Channel.Type.StreamTube */
+ /* im.telepathy.v1.Channel.Type.StreamTube */
g_value_set_static_string (channel_type_value,
TP_IFACE_CHANNEL_TYPE_STREAM_TUBE1);
func (type, table, salut_tube_stream_channel_get_allowed_properties (),
diff --git a/src/tube-dbus.c b/src/tube-dbus.c
index ebe9a17b..fddf54e4 100644
--- a/src/tube-dbus.c
+++ b/src/tube-dbus.c
@@ -1536,7 +1536,7 @@ salut_tube_dbus_check_access_control (SalutTubeDBus *self,
* salut_tube_dbus_offer_async
*
* Implement D-Bus method Offer on interface
- * im.telepathy1.Channel.Type.DBusTube
+ * im.telepathy.v1.Channel.Type.DBusTube
*/
static void
salut_tube_dbus_offer_async (TpSvcChannelTypeDBusTube1 *self,
@@ -1576,7 +1576,7 @@ salut_tube_dbus_offer_async (TpSvcChannelTypeDBusTube1 *self,
* salut_tube_dbus_accept_async
*
* Implements D-Bus method Accept on interface
- * im.telepathy1.Channel.Type.DBusTube
+ * im.telepathy.v1.Channel.Type.DBusTube
*/
static void
salut_tube_dbus_accept_async (TpSvcChannelTypeDBusTube1 *self,
diff --git a/src/tube-stream.c b/src/tube-stream.c
index 06e5d6d7..cbed76c8 100644
--- a/src/tube-stream.c
+++ b/src/tube-stream.c
@@ -2053,7 +2053,7 @@ salut_tube_stream_check_params (TpSocketAddressType address_type,
* salut_tube_stream_offer_async
*
* Implements D-Bus method Offer
- * on im.telepathy1.Channel.Type.StreamTube
+ * on im.telepathy.v1.Channel.Type.StreamTube
*/
static void
salut_tube_stream_offer_async (TpSvcChannelTypeStreamTube1 *iface,
@@ -2110,7 +2110,7 @@ salut_tube_stream_offer_async (TpSvcChannelTypeStreamTube1 *iface,
* salut_tube_stream_accept_async
*
* Implements D-Bus method Accept
- * on im.telepathy1.Channel.Type.StreamTube
+ * on im.telepathy.v1.Channel.Type.StreamTube
*/
static void
salut_tube_stream_accept_async (TpSvcChannelTypeStreamTube1 *iface,
diff --git a/tests/twisted/avahi/caps-self.py b/tests/twisted/avahi/caps-self.py
index c176691b..8e0bab2f 100644
--- a/tests/twisted/avahi/caps-self.py
+++ b/tests/twisted/avahi/caps-self.py
@@ -1,6 +1,6 @@
"""
Basic test of SetSelfCapabilities on interface
-im.telepathy1.Connection.Interface.ContactCapabilities
+im.telepathy.v1.Connection.Interface.ContactCapabilities
"""
from saluttest import exec_test
diff --git a/tests/twisted/avahi/close-local-pending-room.py b/tests/twisted/avahi/close-local-pending-room.py
index 5066fcfd..c1f201a5 100644
--- a/tests/twisted/avahi/close-local-pending-room.py
+++ b/tests/twisted/avahi/close-local-pending-room.py
@@ -72,7 +72,7 @@ def test(q, bus, conn):
q.expect('dbus-signal', signal='MembersChanged', path=path)
- lp_members = props_iface.Get('im.telepathy1.Channel.Interface.Group1',
+ lp_members = props_iface.Get('im.telepathy.v1.Channel.Interface.Group1',
'LocalPendingMembers')
assert len(lp_members) == 1
diff --git a/tests/twisted/avahi/file-transfer/file_transfer_helper.py b/tests/twisted/avahi/file-transfer/file_transfer_helper.py
index edfb1989..cb1fc5be 100644
--- a/tests/twisted/avahi/file-transfer/file_transfer_helper.py
+++ b/tests/twisted/avahi/file-transfer/file_transfer_helper.py
@@ -246,7 +246,7 @@ class ReceiveFileTest(FileTransferTest):
path, props = channels[0]
# check channel properties
- # im.telepathy1.Channel D-Bus properties
+ # im.telepathy.v1.Channel D-Bus properties
assert props[cs.CHANNEL_TYPE] == cs.CHANNEL_TYPE_FILE_TRANSFER
assert props[cs.INTERFACES] == []
assert props[cs.TARGET_HANDLE] == self.handle
@@ -256,7 +256,7 @@ class ReceiveFileTest(FileTransferTest):
assert props[cs.INITIATOR_HANDLE] == self.handle
assert props[cs.INITIATOR_ID] == self.contact_name
- # im.telepathy1.Channel.Type.FileTransfer D-Bus properties
+ # im.telepathy.v1.Channel.Type.FileTransfer D-Bus properties
assert props[cs.FT_STATE] == cs.FT_STATE_PENDING
assert props[cs.FT_CONTENT_TYPE] == self.file.content_type
assert props[cs.FT_FILENAME] == self.file.name
@@ -410,7 +410,7 @@ class SendFileTest(FileTransferTest):
self.ft_path, props = self.conn.Requests.CreateChannel(request)
- # im.telepathy1.Channel D-Bus properties
+ # im.telepathy.v1.Channel D-Bus properties
assert props[cs.CHANNEL_TYPE] == cs.CHANNEL_TYPE_FILE_TRANSFER
assert props[cs.INTERFACES] == []
assert props[cs.TARGET_HANDLE] == self.handle
@@ -420,7 +420,7 @@ class SendFileTest(FileTransferTest):
assert props[cs.INITIATOR_HANDLE] == self.self_handle
assert props[cs.INITIATOR_ID] == self.self_handle_name
- # im.telepathy1.Channel.Type.FileTransfer D-Bus properties
+ # im.telepathy.v1.Channel.Type.FileTransfer D-Bus properties
assert props[cs.FT_STATE] == cs.FT_STATE_PENDING
assert props[cs.FT_CONTENT_TYPE] == self.file.content_type
assert props[cs.FT_FILENAME] == self.file.name
diff --git a/tests/twisted/avahi/muc-invite.py b/tests/twisted/avahi/muc-invite.py
index 6f0a6116..c07bea2e 100644
--- a/tests/twisted/avahi/muc-invite.py
+++ b/tests/twisted/avahi/muc-invite.py
@@ -80,7 +80,7 @@ def test(q, bus, conn):
channel_group = make_channel_proxy(conn, path, "Channel.Interface.Group")
# check channel properties
- # im.telepathy1.Channel D-Bus properties
+ # im.telepathy.v1.Channel D-Bus properties
assert props[cs.CHANNEL_TYPE] == cs.CHANNEL_TYPE_TEXT
assertContains(cs.CHANNEL_IFACE_GROUP, props[cs.INTERFACES])
assert props[cs.TARGET_ID] == 'my-room'
diff --git a/tests/twisted/avahi/olpc-activity-announcements.py b/tests/twisted/avahi/olpc-activity-announcements.py
index 93dbd1a6..a883d920 100644
--- a/tests/twisted/avahi/olpc-activity-announcements.py
+++ b/tests/twisted/avahi/olpc-activity-announcements.py
@@ -13,7 +13,7 @@ import time
import dbus
import socket
-CHANNEL_TYPE_TEXT = "im.telepathy1.Channel.Type.Text"
+CHANNEL_TYPE_TEXT = "im.telepathy.v1.Channel.Type.Text"
HT_CONTACT = 1
HT_ROOM = 2
HT_CONTACT_LIST = 3
diff --git a/tests/twisted/avahi/tubes/tubetestutil.py b/tests/twisted/avahi/tubes/tubetestutil.py
index 4e342f9e..a8bbcaa3 100644
--- a/tests/twisted/avahi/tubes/tubetestutil.py
+++ b/tests/twisted/avahi/tubes/tubetestutil.py
@@ -56,7 +56,7 @@ def connect_two_accounts(q, bus, conn):
# property first
contact1_handle_on_conn2 = 0
conn2_members = conn2_publish_proxy.Get(
- 'im.telepathy1.Channel.Interface.Group', 'Members',
+ 'im.telepathy.v1.Channel.Interface.Group', 'Members',
dbus_interface='org.freedesktop.DBus.Properties')
for h in conn2_members:
name = conn2.InspectHandles(cs.HT_CONTACT, [h])[0]
diff --git a/tests/twisted/avahi/tubes/two-muc-dbus-tubes.py b/tests/twisted/avahi/tubes/two-muc-dbus-tubes.py
index ae8864c3..42ef1743 100644
--- a/tests/twisted/avahi/tubes/two-muc-dbus-tubes.py
+++ b/tests/twisted/avahi/tubes/two-muc-dbus-tubes.py
@@ -21,9 +21,9 @@ def check_dbus_names(tube, members):
names = tube.Properties.Get(cs.CHANNEL_TYPE_DBUS_TUBE, 'DBusNames')
assert set(names.keys()) == set(members), names.keys()
-SERVICE = "im.telepathy1.Tube.Test"
+SERVICE = "im.telepathy.v1.Tube.Test"
IFACE = SERVICE
-PATH = "/im/telepathy1/Tube/Test"
+PATH = "/im/telepathy/v1/Tube/Test"
print "FIXME: MUC tubes tests are currently broken: fdo#69223"
# exiting 77 causes automake to consider the test to have been skipped
diff --git a/tests/twisted/constants.py b/tests/twisted/constants.py
index e72c5928..a9181acc 100644
--- a/tests/twisted/constants.py
+++ b/tests/twisted/constants.py
@@ -22,7 +22,7 @@ Some handy constants for other tests to share and enjoy.
from dbus import PROPERTIES_IFACE, INTROSPECTABLE_IFACE
-PREFIX = "im.telepathy1"
+PREFIX = "im.telepathy.v1"
PATH_PREFIX = '/' + PREFIX.replace('.', '/')
tp_name_prefix = PREFIX
diff --git a/tests/twisted/sidecars.py b/tests/twisted/sidecars.py
index 137a27f8..87941f07 100644
--- a/tests/twisted/sidecars.py
+++ b/tests/twisted/sidecars.py
@@ -9,7 +9,7 @@ from saluttest import exec_test
import constants as cs
from config import PLUGINS_ENABLED
-TEST_PLUGIN_IFACE = "im.telepathy1.Salut.Plugin.Test"
+TEST_PLUGIN_IFACE = "im.telepathy.v1.Salut.Plugin.Test"
if not PLUGINS_ENABLED:
print "NOTE: built without --enable-plugins, not testing plugins"
diff --git a/tests/twisted/tools/Makefile.am b/tests/twisted/tools/Makefile.am
index bab9999f..97d62f71 100644
--- a/tests/twisted/tools/Makefile.am
+++ b/tests/twisted/tools/Makefile.am
@@ -8,12 +8,12 @@ exec-with-log.sh: exec-with-log.sh.in
# We don't use the full filename for the .in because > 99 character filenames
# in tarballs are non-portable (and automake 1.8 doesn't let us build
# non-archaic tarballs)
-im.telepathy1.ConnectionManager.%.service: %.service.in
+im.telepathy.v1.ConnectionManager.%.service: %.service.in
$(AM_V_GEN)sed -e "s|[@]abs_top_builddir[@]|@abs_top_builddir@|g" $< > $@
# D-Bus service file for testing
service_in_files = salut.service.in
-service_files = im.telepathy1.ConnectionManager.salut.service
+service_files = im.telepathy.v1.ConnectionManager.salut.service
# D-Bus config file for testing
conf_in_files = tmp-session-bus.conf.in
diff --git a/tests/twisted/tools/salut.service.in b/tests/twisted/tools/salut.service.in
index c517ba10..2ebde940 100644
--- a/tests/twisted/tools/salut.service.in
+++ b/tests/twisted/tools/salut.service.in
@@ -1,3 +1,3 @@
[D-BUS Service]
-Name=im.telepathy1.ConnectionManager.salut
+Name=im.telepathy.v1.ConnectionManager.salut
Exec=@abs_top_builddir@/tests/twisted/tools/exec-with-log.sh
diff --git a/src/roomlist-channel.c b/src/roomlist-channel.c
index 1e59822f..f50bc417 100644
--- a/src/roomlist-channel.c
+++ b/src/roomlist-channel.c
@@ -247,7 +247,7 @@ salut_roomlist_channel_add_room (SalutRoomlistChannel *self,
dbus_g_type_specialized_construct (TP_STRUCT_TYPE_ROOM_INFO));
dbus_g_type_struct_set (&room,
0, handle,
- 1, "im.telepathy1.Channel.Type.Text",
+ 1, "im.telepathy.v1.Channel.Type.Text",
2, keys,
G_MAXUINT);
g_ptr_array_add (priv->rooms, g_value_get_boxed (&room));
@@ -299,7 +299,7 @@ salut_roomlist_channel_remove_room (SalutRoomlistChannel *self,
* salut_roomlist_channel_get_listing_rooms
*
* Implements D-Bus method GetListingRooms
* on interface im.telepathy1.Channel.Type.RoomList
*
* @error: Used to return a pointer to a GError detailing any error
* that occurred, D-Bus will throw the error only if this
@@ -324,7 +324,7 @@ salut_roomlist_channel_get_listing_rooms (TpSvcChannelTypeRoomList1 *iface,
* salut_roomlist_channel_list_rooms
*
* Implements D-Bus method ListRooms
* on interface im.telepathy1.Channel.Type.RoomList
*
* @error: Used to return a pointer to a GError detailing any error
* that occurred, D-Bus will throw the error only if this
@@ -350,7 +350,7 @@ salut_roomlist_channel_list_rooms (TpSvcChannelTypeRoomList1 *iface,
* salut_roomlist_channel_stop_listing
*
* Implements D-Bus method StopListing
* on interface im.telepathy1.Channel.Type.RoomList
*/
static void
salut_roomlist_channel_stop_listing (TpSvcChannelTypeRoomList1 *iface,
@@ -299,7 +299,7 @@ salut_roomlist_channel_remove_room (SalutRoomlistChannel *self,
*
* Implements D-Bus method GetListingRooms
- * on interface im.telepathy1.Channel.Type.RoomList
+ * on interface im.telepathy.v1.Channel.Type.RoomList
*
* @error: Used to return a pointer to a GError detailing any error
@@ -324,7 +324,7 @@ salut_roomlist_channel_get_listing_rooms (TpSvcChannelTypeRoomList1 *iface,
*
* Implements D-Bus method ListRooms
- * on interface im.telepathy1.Channel.Type.RoomList
+ * on interface im.telepathy.v1.Channel.Type.RoomList
*
* @error: Used to return a pointer to a GError detailing any error
@@ -350,7 +350,7 @@ salut_roomlist_channel_list_rooms (TpSvcChannelTypeRoomList1 *iface,
*
* Implements D-Bus method StopListing
- * on interface im.telepathy1.Channel.Type.RoomList
+ * on interface im.telepathy.v1.Channel.Type.RoomList
*/
static void